==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QColumnView_shell.h <==
#ifndef QCOLUMNVIEW_SHELL_H
#define QCOLUMNVIEW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(columnview)
#include <QtWidgets/qcolumnview.h>
#endif //QT_CONFIG(columnview)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemview.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(columnview)

class QColumnView_shell : public QColumnView, public QtJambiShellInterface
{
public:
    QColumnView_shell(QWidget* parent0 = nullptr);
    ~QColumnView_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void closeEditor(QWidget* editor0, QAbstractItemDelegate::EndEditHint hint1) override;
    void closeEvent(QCloseEvent* event0) override;
    void commitData(QWidget* editor0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* arg__1) override;
    QAbstractItemView* createColumn(const QModelIndex& rootIndex0) override;
    void currentChanged(const QModelIndex& current0, const QModelIndex& previous1) override;
    void customEvent(QEvent* event0) override;
    void dataChanged(const QModelIndex& topLeft0, const QModelIndex& bottomRight1, const QVector<int>& roles2) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void doItemsLayout() override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    bool edit(const QModelIndex& index0, QAbstractItemView::EditTrigger trigger1, QEvent* event2) override;
    void editorDestroyed(QObject* editor0) override;
    void enterEvent(QEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* object0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    int horizontalOffset() const override;
    void horizontalScrollbarAction(int action0) override;
    void horizontalScrollbarValueChanged(int value0) override;
    QModelIndex indexAt(const QPoint& point0) const override;
    void initPainter(QPainter* painter0) const override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isIndexHidden(const QModelIndex& index0) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void keyboardSearch(const QString& search0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    QModelIndex moveCursor(QAbstractItemView::CursorAction cursorAction0, Qt::KeyboardModifiers modifiers1) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* arg__1) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void reset() override;
    void resizeEvent(QResizeEvent* event0) override;
    void rowsAboutToBeRemoved(const QModelIndex& parent0, int start1, int end2) override;
    void rowsInserted(const QModelIndex& parent0, int start1, int end2) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void scrollTo(const QModelIndex& index0, QAbstractItemView::ScrollHint hint1) override;
    void selectAll() override;
    QList<QModelIndex> selectedIndexes() const override;
    void selectionChanged(const QItemSelection& selected0, const QItemSelection& deselected1) override;
    QItemSelectionModel::SelectionFlags selectionCommand(const QModelIndex& index0, const QEvent* event1) const override;
    void setModel(QAbstractItemModel* model0) override;
    void setRootIndex(const QModelIndex& index0) override;
    void setSelection(const QRect& rect0, QItemSelectionModel::SelectionFlags command1) override;
    void setSelectionModel(QItemSelectionModel* selectionModel0) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* viewport0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    int sizeHintForColumn(int column0) const override;
    int sizeHintForRow(int row0) const override;
    void startDrag(Qt::DropActions supportedActions0) override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void updateEditorData() override;
    void updateEditorGeometries() override;
    void updateGeometries() override;
    int verticalOffset() const override;
    void verticalScrollbarAction(int action0) override;
    void verticalScrollbarValueChanged(int value0) override;
    QStyleOptionViewItem viewOptions() const override;
    bool viewportEvent(QEvent* event0) override;
    QSize viewportSizeHint() const override;
    QRect visualRect(const QModelIndex& index0) const override;
    QRegion visualRegionForSelection(const QItemSelection& selection0) const override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QColumnView_access : public QColumnView
{
    void __qt_initializeColumn_QAbstractItemView_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID column0) const;
    jobject __qt_createColumn_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rootIndex0);
    void __qt_currentChanged_cref_QModelIndex_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID current0, QtJambiNativeID previous1);
    jint __qt_horizontalOffset_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_indexAt_cref_QPoint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0) const;
    jboolean __qt_isIndexHidden_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jobject __qt_moveCursor_QAbstractItemView_CursorAction_Qt_KeyboardModifiers(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cursorAction0, jint modifiers1);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_rowsInserted_cref_QModelIndex_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jint start1, jint end2);
    void __qt_scrollContentsBy_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint dx0, jint dy1);
    void __qt_scrollTo_cref_QModelIndex_QAbstractItemView_ScrollHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jint hint1);
    void __qt_selectAll(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID model0);
    void __qt_setRootIndex_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0);
    void __qt_setSelection_cref_QRect_QItemSelectionModel_SelectionFlags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0, jint command1);
    void __qt_setSelectionModel_QItemSelectionModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID selectionModel0);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_verticalOffset_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_visualRect_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jobject __qt_visualRegionForSelection_cref_QItemSelection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID selection0) const;
};

#endif // QT_CONFIG(columnview)
#endif // QCOLUMNVIEW_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiWidgets/QColumnView_shell.h <==
#ifndef QCOLUMNVIEW_SHELL_H
#define QCOLUMNVIEW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(columnview)
#include <QtWidgets/qcolumnview.h>
#endif //QT_CONFIG(columnview)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemview.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(columnview)

class QColumnView_shell : public QColumnView, public QtJambiShellInterface
{
public:
    QColumnView_shell(QWidget* parent0 = nullptr);
    ~QColumnView_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QColumnView_mshell;
    friend class QColumnView_oshell;
};


class QColumnView_mshell : public QColumnView_shell
{
public:
    using QColumnView_shell::QColumnView_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QColumnView_oshell : public QColumnView_mshell
{
public:
    using QColumnView_mshell::QColumnView_mshell;
    ~QColumnView_oshell() override;
    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void closeEditor(QWidget* editor0, QAbstractItemDelegate::EndEditHint hint1) override;
    void closeEvent(QCloseEvent* event0) override;
    void commitData(QWidget* editor0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* arg__1) override;
    QAbstractItemView* createColumn(const QModelIndex& rootIndex0) override;
    void currentChanged(const QModelIndex& current0, const QModelIndex& previous1) override;
    void customEvent(QEvent* event0) override;
    void dataChanged(const QModelIndex& topLeft0, const QModelIndex& bottomRight1, const QList<int>& roles2) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void doItemsLayout() override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    bool edit(const QModelIndex& index0, QAbstractItemView::EditTrigger trigger1, QEvent* event2) override;
    void editorDestroyed(QObject* editor0) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* object0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    int horizontalOffset() const override;
    void horizontalScrollbarAction(int action0) override;
    void horizontalScrollbarValueChanged(int value0) override;
    QModelIndex indexAt(const QPoint& point0) const override;
    void initPainter(QPainter* painter0) const override;
    void initStyleOption(QStyleOptionFrame* option0) const override;
    void initViewItemOption(QStyleOptionViewItem* option0) const override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isIndexHidden(const QModelIndex& index0) const override;
    QAbstractItemDelegate* itemDelegateForIndex(const QModelIndex& index0) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void keyboardSearch(const QString& search0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    QModelIndex moveCursor(QAbstractItemView::CursorAction cursorAction0, Qt::KeyboardModifiers modifiers1) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* arg__1) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void reset() override;
    void resizeEvent(QResizeEvent* event0) override;
    void rowsAboutToBeRemoved(const QModelIndex& parent0, int start1, int end2) override;
    void rowsInserted(const QModelIndex& parent0, int start1, int end2) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void scrollTo(const QModelIndex& index0, QAbstractItemView::ScrollHint hint1) override;
    void selectAll() override;
    QList<QModelIndex> selectedIndexes() const override;
    void selectionChanged(const QItemSelection& selected0, const QItemSelection& deselected1) override;
    QItemSelectionModel::SelectionFlags selectionCommand(const QModelIndex& index0, const QEvent* event1) const override;
    void setModel(QAbstractItemModel* model0) override;
    void setRootIndex(const QModelIndex& index0) override;
    void setSelection(const QRect& rect0, QItemSelectionModel::SelectionFlags command1) override;
    void setSelectionModel(QItemSelectionModel* selectionModel0) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* viewport0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    int sizeHintForColumn(int column0) const override;
    int sizeHintForRow(int row0) const override;
    void startDrag(Qt::DropActions supportedActions0) override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void updateEditorData() override;
    void updateEditorGeometries() override;
    void updateGeometries() override;
    int verticalOffset() const override;
    void verticalScrollbarAction(int action0) override;
    void verticalScrollbarValueChanged(int value0) override;
    bool viewportEvent(QEvent* event0) override;
    QSize viewportSizeHint() const override;
    QRect visualRect(const QModelIndex& index0) const override;
    QRegion visualRegionForSelection(const QItemSelection& selection0) const override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QColumnView_access : public QColumnView
{
    void __qt_initializeColumn_QAbstractItemView_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID column0) const;
    jobject __qt_createColumn_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rootIndex0);
    void __qt_currentChanged_cref_QModelIndex_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID current0, QtJambiNativeID previous1);
    jint __qt_horizontalOffset_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_indexAt_cref_QPoint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0) const;
    jboolean __qt_isIndexHidden_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jobject __qt_moveCursor_QAbstractItemView_CursorAction_Qt_KeyboardModifiers(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cursorAction0, jint modifiers1);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_rowsInserted_cref_QModelIndex_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jint start1, jint end2);
    void __qt_scrollContentsBy_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint dx0, jint dy1);
    void __qt_scrollTo_cref_QModelIndex_QAbstractItemView_ScrollHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jint hint1);
    void __qt_selectAll(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID model0);
    void __qt_setRootIndex_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0);
    void __qt_setSelection_cref_QRect_QItemSelectionModel_SelectionFlags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0, jint command1);
    void __qt_setSelectionModel_QItemSelectionModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID selectionModel0);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_verticalOffset_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_visualRect_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jobject __qt_visualRegionForSelection_cref_QItemSelection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID selection0) const;
};

#endif // QT_CONFIG(columnview)
#endif // QCOLUMNVIEW_SHELL_H
